@@ -13,8 +13,8 @@
 G_BEGIN_DECLS
 
 #define SOUP_MAJOR_VERSION (2)
-#define SOUP_MINOR_VERSION (68)
-#define SOUP_MICRO_VERSION (4)
+#define SOUP_MINOR_VERSION (70)
+#define SOUP_MICRO_VERSION (0)
 
 #define SOUP_CHECK_VERSION(major, minor, micro) \
     (SOUP_MAJOR_VERSION > (major) || \
@@ -68,6 +68,7 @@ G_BEGIN_DECLS
 #define SOUP_VERSION_2_62 (G_ENCODE_VERSION (2, 62))
 #define SOUP_VERSION_2_66 (G_ENCODE_VERSION (2, 66))
 #define SOUP_VERSION_2_68 (G_ENCODE_VERSION (2, 68))
+#define SOUP_VERSION_2_70 (G_ENCODE_VERSION (2, 70))
 
 /* evaluates to the current stable version; for development cycles,
  * this means the next stable target
@@ -396,6 +397,19 @@ G_BEGIN_DECLS
 # define SOUP_AVAILABLE_IN_2_68                 _SOUP_EXTERN
 #endif
 
+#if SOUP_VERSION_MIN_REQUIRED >= SOUP_VERSION_2_70
+# define SOUP_DEPRECATED_IN_2_70                G_DEPRECATED
+# define SOUP_DEPRECATED_IN_2_70_FOR(f)         G_DEPRECATED_FOR(f)
+#else
+# define SOUP_DEPRECATED_IN_2_70
+# define SOUP_DEPRECATED_IN_2_70_FOR(f)
+#endif
+
+#if SOUP_VERSION_MAX_ALLOWED < SOUP_VERSION_2_70
+# define SOUP_AVAILABLE_IN_2_70                 G_UNAVAILABLE(2, 70) _SOUP_EXTERN
+#else
+# define SOUP_AVAILABLE_IN_2_70                 _SOUP_EXTERN
+#endif
 SOUP_AVAILABLE_IN_2_42
 guint    soup_get_major_version (void);
 
